@@ -3,7 +3,6 @@ use strict;
 use base qw/Pod::ProjectDocs::File/;
 use MIME::Base64;
 use File::Basename;
-use File::Spec::Functions qw/abs2rel/;
 
 __PACKAGE__->default_name('up.gif');
 __PACKAGE__->data( do{ local $/; <DATA> } );
@@ -13,7 +12,7 @@ sub tag {
 	my $self = shift;
 	my $file = shift;
 	my($name, $path) = fileparse $file->path, qw/\.html/;
-	my $rel_path = abs2rel $self->path, $path;
+	my $rel_path = File::Spec->abs2rel($self->path, $path);
 	return sprintf qq|<a href="#TOP" class="toplink"><img alt="^" src="%s"></a>|, $rel_path;
 }
 
